import React from "react";
import { createStyles, makeStyles, withStyles, } from "@material-ui/core/styles";
import MenuItem from "@material-ui/core/MenuItem";
import FormControl from "@material-ui/core/FormControl";
import Select from "@material-ui/core/Select";
import Chip from "@material-ui/core/Chip";
import InputBase from "@material-ui/core/InputBase";
import ArrowDropDownRoundedIcon from "@material-ui/icons/ArrowDropDownRounded";
import { ListItemText } from "@material-ui/core";
/**Styling for Input Text Field */
const BootstrapInput = withStyles((theme) => createStyles({
    root: {
        "label + &": {
            marginTop: theme.spacing(3),
        },
    },
    input: {
        borderRadius: "4px",
        position: "relative",
        backgroundColor: theme.palette.background.paper,
        border: "1px solid #E3E4E5",
        fontSize: 16,
        padding: "2px 7px 2px",
        minHeight: "28px",
        transition: theme.transitions.create(["border-color", "box-shadow"]),
        "&:focus": {
            borderRadius: "5px",
            borderColor: "#91959A",
        },
    },
}))(InputBase);
const useStyles = makeStyles((theme) => createStyles({
    select: {
        "&:focus": {
            backgroundColor: "white",
        },
    },
    formControl: {
        minWidth: 800,
        maxWidth: 800,
    },
    chips: {
        display: "flex",
        flexWrap: "wrap",
    },
    chip: {
        margin: 2,
    },
    noLabel: {
        marginTop: theme.spacing(3),
    },
}));
/**Styling for Dropdown Menu */
const ITEM_HEIGHT = 48;
const ITEM_PADDING_TOP = 8;
const MenuProps = {
    PaperProps: {
        style: {
            maxHeight: ITEM_HEIGHT * 4.5 + ITEM_PADDING_TOP,
            width: 250,
            overflow: "auto",
        },
    },
};
export default function SelectMultiple(inputProps) {
    const classes = useStyles();
    /**Changes the selectedList whenever the user selects/deselects in dropdown menu */
    const handleChange = (event) => {
        inputProps.setSelectedList(event.target.value);
    };
    /**Removes the id when the user cicks remove icon in Chip */
    const handleDelete = (data) => {
        let filteredList = inputProps.selectedList;
        filteredList = filteredList.filter((val) => val !== data);
        inputProps.setSelectedList(filteredList);
    };
    return (React.createElement("div", null,
        React.createElement(FormControl, { className: classes.formControl },
            React.createElement(Select, { IconComponent: () => (React.createElement(ArrowDropDownRoundedIcon, { style: {
                        color: "#444B53",
                        fontSize: "22px",
                        right: "0",
                        position: "absolute",
                    } })), labelId: "demo-mutiple-chip-label", id: "demo-mutiple-chip", multiple: true, value: inputProps.selectedList, onChange: handleChange, input: React.createElement(BootstrapInput, null), renderValue: (selected) => (React.createElement("div", { className: classes.chips }, selected.map((value) => {
                    var _a;
                    return (React.createElement(Chip, { key: value, size: "small", onMouseDown: (event) => {
                            event.stopPropagation();
                        }, onDelete: () => handleDelete(value), label: (_a = inputProps.totalListData.find((option) => option.id == value)) === null || _a === void 0 ? void 0 : _a.value, className: classes.chip }));
                }))), MenuProps: MenuProps }, inputProps.totalListData.map((option) => (React.createElement(MenuItem, { key: option.id, value: option.id },
                React.createElement(ListItemText, { primary: option.value }))))))));
}
